# OctoPrintServerRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**base_path** | **str** |  | 
**venv_path** | **str** |  | 
**pip_path** | **str** |  | 
**python_path** | **str** |  | 
**octoprint_version** | **str** |  | [optional] 
**pip_version** | **str** |  | [optional] 
**python_version** | **str** |  | [optional] 
**printnanny_plugin_version** | **str** |  | [optional] 
**pi** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


